from setuptools import setup, find_packages

setup(
    name="dolev_dublon",
    version="0.0.3",
    author="dolev dublon",
    author_email="dolev146@gmail.com",
    description="A package for dolev",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
